@@ -1,5 +1,5 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, DUMMY_NODE};
+use super::{Context, LintRule};
 use crate::swc_util::StringRepr;
 use crate::ProgramRef;
 use std::sync::Arc;
@@ -18,7 +18,6 @@ use deno_ast::swc::ast::Prop;
 use deno_ast::swc::ast::PropOrSpread;
 use deno_ast::swc::common::Span;
 use deno_ast::swc::visit::noop_visit_type;
-use deno_ast::swc::visit::Node;
 use deno_ast::swc::visit::{VisitAll, VisitAllWith};
 use derive_more::Display;
 
@@ -61,8 +60,8 @@ impl LintRule for NoSelfAssign {
   ) {
     let mut visitor = NoSelfAssignVisitor::new(context);
     match program {
-      ProgramRef::Module(m) => m.visit_all_with(&DUMMY_NODE, &mut visitor),
-      ProgramRef::Script(s) => s.visit_all_with(&DUMMY_NODE, &mut visitor),
+      ProgramRef::Module(m) => m.visit_all_with(&mut visitor),
+      ProgramRef::Script(s) => s.visit_all_with(&mut visitor),
     }
   }
 
@@ -301,11 +300,7 @@ impl<'c, 'view> NoSelfAssignVisitor<'c, 'view> {
 impl<'c, 'view> VisitAll for NoSelfAssignVisitor<'c, 'view> {
   noop_visit_type!();
 
-  fn visit_assign_expr(
-    &mut self,
-    assign_expr: &AssignExpr,
-    _parent: &dyn Node,
-  ) {
+  fn visit_assign_expr(&mut self, assign_expr: &AssignExpr) {
     if assign_expr.op == AssignOp::Assign {
       match &assign_expr.left {
         PatOrExpr::Pat(l_pat) => {
